
--- Module implementing the LuaRocks "help" command.
-- This is a generic help display module, which
-- uses a global table called "commands" to find commands
-- to show help for; each command should be represented by a
-- table containing "help" and "help_summary" fields.
module("luarocks.help", package.seeall)

help_summary = "Help on commands"

help = [[
<argument> is the command to show help for.
]]

--- Driver function for the "help" command.
-- @param command string or nil: command to show help for; if not
-- given, help summaries for all commands are shown.
-- @return boolean or (nil, string): true if there were no errors
-- or nil and an error message if an invalid command was requested.
function run(command)
   if not command then
      print([[
LuaRocks, a module deployment system for Lua

]]..program_name..[[ - ]]..program_description..[[

usage: ]]..program_name..[[ [VAR=VALUE]... <command> [<argument>]

Variables from the "variables" table of the configuration file
can be overriden with VAR=VALUE assignments.

Supported commands:
]])
      for name, command in pairs(commands) do
         print(name, command.help_summary)
      end
   else
      command = command:gsub("-", "_")
      if commands[command] then
         print(program_name.." "..command.." [<arguments>]")
         print()
         print(command.." - "..commands[command].help_summary)
         print()
         print(commands[command].help)
      else
         return nil, "Unknown command '"..command.."'"
      end
   end
   return true
end
